@@ -1,4 +1,5 @@
 // External libraries are lazy-loaded only if these file types exist.
+const util = require("util");
 var Yaml = null,
     VisionmediaYaml = null,
     Coffee = null,
@@ -48,13 +49,19 @@ Parser.xmlParser = function(filename, content) {
 };
 
 Parser.jsParser = function(filename, content) {
-  return require(filename);
+  var configObject = require(filename);
+
+  if (configObject.__esModule && util.isObject(configObject.default)) {
+    return configObject.default
+  }
+  return configObject;
 };
 
 Parser.tsParser = function(filename, content) {
   if (!require.extensions['.ts']) {
     require(TS_DEP).register({
       lazy: true,
+      ignore: ['(?:^|/)node_modules/', '.*(?<!\.ts)$'],
       transpileOnly: true,
       compilerOptions: {
         allowJs: true,
@@ -148,20 +155,14 @@ Parser.yamlParser = function(filename, content) {
 };
 
 Parser.jsonParser = function(filename, content) {
-  try {
-    return JSON.parse(content);
-  }
-  catch (e) {
-    // All JS Style comments will begin with /, so all JSON parse errors that
-    // encountered a syntax error will complain about this character.
-    if (e.name !== 'SyntaxError' || e.message.indexOf('Unexpected token /') !== 0) {
-      throw e;
-    }
-    if (!JSON5) {
-      JSON5 = require(JSON5_DEP);
-    }
+  /**
+   * Default JSON parsing to JSON5 parser.
+   * This is due to issues with removing supported comments.
+   * More information can be found here: https://github.com/node-config/node-config/issues/715
+   */
+    JSON5 = require(JSON5_DEP);
+
     return JSON5.parse(content);
-  }
 };
 
 Parser.json5Parser = function(filename, content) {
@@ -191,9 +192,9 @@ Parser.csonParser = function(filename, content) {
   }
   // Allow comments in CSON files
   if (typeof CSON.parseSync === 'function') {
-    return CSON.parseSync(Parser.stripComments(content));
+    return CSON.parseSync(content);
   }
-  return CSON.parse(Parser.stripComments(content));
+  return CSON.parse(content);
 };
 
 Parser.propertiesParser = function(filename, content) {
@@ -220,7 +221,7 @@ Parser.propertiesParser = function(filename, content) {
  * @return {string} The string with comments stripped.
  */
 Parser.stripComments = function(fileStr, stringRegex) {
-  stringRegex = stringRegex || /(['"])(\\\1|.)+?\1/g;
+  stringRegex = stringRegex || /"((?:[^"\\]|\\.)*)"/g;
 
   var uid = '_' + +new Date(),
     primitives = [],
