@@ -261,9 +261,13 @@ vows.describe('Test suite for node-config')
 
   'Assuring a configuration array property can be made immutable': {
     'Correctly unable to change an immutable configuration': function() {
-      CONFIG.util.makeImmutable(CONFIG.TestModule, 'arr1');
-      CONFIG.TestModule.arr1 = ['bad value'];
-      assert.isTrue(CONFIG.TestModule.arr1[0] == 'arrValue1');
+      assert.throws(
+        function() {
+          CONFIG.util.makeImmutable(CONFIG.TestModule, 'arr1');
+          CONFIG.TestModule.arr1 = [ 'bad value' ];
+        },
+        /Can not update runtime configuration property: "arr1"\. Configuration objects are immutable unless ALLOW_CONFIG_MUTATIONS is set\./
+      )
     },
 
     'Correctly unable to add values to immutable array': function() {
@@ -392,7 +396,7 @@ vows.describe('Test suite for node-config')
       assert.deepEqual(MODULE_CONFIG.TestModule, moduleConfig);
     },
 
-    // Regression test for https://github.com/lorenwest/node-config/issues/518
+    // Regression test for https://github.com/node-config/node-config/issues/518
     'The module config did not extend itself with its own name': function(moduleConfig) {
       assert.isFalse('TestModule' in moduleConfig);
       assert.isFalse('TestModule' in MODULE_CONFIG.TestModule);
